From c21517f02d7c71be3bd4667549756f00923feabb Mon Sep 17 00:00:00 2001
From: Didier Raboud <odyx@debian.org>
Date: Tue, 25 Feb 2014 16:47:34 +0100
Subject: [PATCH] In postinst scripts, only chown and chmod when no
 dpkg-statoverrides are set

Closes: #587015
---
 debian/cups-client.postinst |  7 +++++--
 debian/cups-daemon.postinst | 12 ++++++------
 debian/cups.postinst        |  7 +++++--
 3 files changed, 16 insertions(+), 10 deletions(-)

diff --git a/debian/cups-client.postinst b/debian/cups-client.postinst
index 4f1af8c..b14e91d 100644
--- a/debian/cups-client.postinst
+++ b/debian/cups-client.postinst
@@ -8,8 +8,11 @@ case "$1" in
             addgroup --system lpadmin
         fi
 
-	chown root:lpadmin /usr/bin/lppasswd
-	chmod u+s /usr/bin/lppasswd
+        if ! dpkg-statoverride --list /usr/bin/lppasswd > /dev/null
+        then
+            chown root:lpadmin /usr/bin/lppasswd
+            chmod u+s /usr/bin/lppasswd
+        fi
     ;;
 
     abort-upgrade|abort-remove|abort-deconfigure)
diff --git a/debian/cups-daemon.postinst b/debian/cups-daemon.postinst
index d22fa0f..258e61f 100644
--- a/debian/cups-daemon.postinst
+++ b/debian/cups-daemon.postinst
@@ -8,12 +8,12 @@ if [ "$1" = configure ]; then
 	addgroup --system lpadmin
     fi
 
-    if [ -f /etc/cups/classes.conf ]; then
-      chown root:lp /etc/cups/classes.conf ; chmod 600 /etc/cups/classes.conf
-    fi
-    if [ -f /etc/cups/printers.conf ]; then
-      chown root:lp /etc/cups/printers.conf ; chmod 600 /etc/cups/printers.conf
-    fi
+    for i in /etc/cups/classes.conf /etc/cups/printers.conf
+    do
+        if [ -f $i ] && ! dpkg-statoverride --list $i > /dev/null; then
+            chown root:lp $i; chmod 600 $i
+        fi
+    done
 
     # symlink snakeoil SSL certificate if present
     if [ -e /etc/ssl/certs/ssl-cert-snakeoil.pem -a \
diff --git a/debian/cups.postinst b/debian/cups.postinst
index 0052736..143d2d2 100644
--- a/debian/cups.postinst
+++ b/debian/cups.postinst
@@ -7,8 +7,11 @@ set -e
 
 if [ "$1" = configure ]; then
     # set up custom PPD directory
-    chown root:lpadmin /usr/share/ppd/custom 2>/dev/null || true
-    chmod 3775 /usr/share/ppd/custom 2>/dev/null || true
+    if ! dpkg-statoverride --list /usr/share/ppd/custom > /dev/null
+    then
+        chown root:lpadmin /usr/share/ppd/custom 2>/dev/null || true
+        chmod 3775 /usr/share/ppd/custom 2>/dev/null || true
+    fi
 
     # Generate raw MIME handling files if they don't already exist.
     if [ ! -e /etc/cups/raw.types ]; then
-- 
1.9.0

